@@ -58,7 +58,11 @@
 
   if (x == y) {
     # Avoid error in the case of perfect correlation
-    rez <- BayesFactor::correlationBF(stats::rnorm(1000), stats::rnorm(1000), rscale = bayesian_prior)
+    rez <- suppressWarnings(BayesFactor::correlationBF(
+      stats::rnorm(1000),
+      stats::rnorm(1000),
+      rscale = bayesian_prior
+    ))
     params <- parameters::model_parameters(
       rez,
       dispersion = FALSE,
@@ -79,7 +83,11 @@
     if ("ROPE_Percentage" %in% names(params)) params$ROPE_Percentage <- 0
     if ("BF" %in% names(params)) params$BF <- Inf
   } else {
-    rez <- BayesFactor::correlationBF(var_x, var_y, rscale = bayesian_prior)
+    rez <- suppressWarnings(BayesFactor::correlationBF(
+      var_x,
+      var_y,
+      rscale = bayesian_prior
+    ))
     params <- parameters::model_parameters(
       rez,
       dispersion = FALSE,
