@@ -1,14 +1,12 @@
 #' @export
-plot.easycormatrix <- function(x, ...) {
-  insight::check_if_installed("see", "to plot correlation graphs")
-
-  NextMethod()
-}
-
-
-#' @export
-plot.easycor_test <- function(x, ...) {
+plot.easycorrelation <- function(x, ...) {
   insight::check_if_installed("see", "to plot correlation graphs")
 
   plot(visualisation_recipe(x, ...), ...)
-}
\ No newline at end of file
+}
+
+#' @export
+plot.easycormatrix <- plot.easycorrelation
+
+#' @export
+plot.easycor_test <- plot.easycorrelation
